/****************************************************************************
** Meta object code from reading C++ file 'edit_dialog.hh'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.8)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "edit_dialog.hh"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'edit_dialog.hh' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.8. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_EditDialog_t {
    QByteArrayData data[27];
    char stringdata0[438];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_EditDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_EditDialog_t qt_meta_stringdata_EditDialog = {
    {
QT_MOC_LITERAL(0, 0, 10), // "EditDialog"
QT_MOC_LITERAL(1, 11, 17), // "select_ingredient"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 11), // "QModelIndex"
QT_MOC_LITERAL(4, 42, 7), // "current"
QT_MOC_LITERAL(5, 50, 8), // "previous"
QT_MOC_LITERAL(6, 59, 12), // "unit_changed"
QT_MOC_LITERAL(7, 72, 3), // "idx"
QT_MOC_LITERAL(8, 76, 23), // "ingredient_name_changed"
QT_MOC_LITERAL(9, 100, 4), // "text"
QT_MOC_LITERAL(10, 105, 19), // "amount_type_changed"
QT_MOC_LITERAL(11, 125, 5), // "value"
QT_MOC_LITERAL(12, 131, 18), // "amount_int_changed"
QT_MOC_LITERAL(13, 150, 20), // "amount_float_changed"
QT_MOC_LITERAL(14, 171, 14), // "add_ingredient"
QT_MOC_LITERAL(15, 186, 17), // "delete_ingredient"
QT_MOC_LITERAL(16, 204, 26), // "ingredient_section_changed"
QT_MOC_LITERAL(17, 231, 22), // "add_ingredient_section"
QT_MOC_LITERAL(18, 254, 18), // "move_ingredient_up"
QT_MOC_LITERAL(19, 273, 20), // "move_ingredient_down"
QT_MOC_LITERAL(20, 294, 18), // "select_instruction"
QT_MOC_LITERAL(21, 313, 15), // "section_changed"
QT_MOC_LITERAL(22, 329, 23), // "add_instruction_section"
QT_MOC_LITERAL(23, 353, 26), // "remove_instruction_section"
QT_MOC_LITERAL(24, 380, 25), // "instructions_text_changed"
QT_MOC_LITERAL(25, 406, 16), // "update_ok_button"
QT_MOC_LITERAL(26, 423, 14) // "unit_converter"

    },
    "EditDialog\0select_ingredient\0\0QModelIndex\0"
    "current\0previous\0unit_changed\0idx\0"
    "ingredient_name_changed\0text\0"
    "amount_type_changed\0value\0amount_int_changed\0"
    "amount_float_changed\0add_ingredient\0"
    "delete_ingredient\0ingredient_section_changed\0"
    "add_ingredient_section\0move_ingredient_up\0"
    "move_ingredient_down\0select_instruction\0"
    "section_changed\0add_instruction_section\0"
    "remove_instruction_section\0"
    "instructions_text_changed\0update_ok_button\0"
    "unit_converter"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_EditDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,  109,    2, 0x0a /* Public */,
       6,    1,  114,    2, 0x0a /* Public */,
       8,    1,  117,    2, 0x0a /* Public */,
      10,    1,  120,    2, 0x0a /* Public */,
      12,    1,  123,    2, 0x0a /* Public */,
      13,    1,  126,    2, 0x0a /* Public */,
      14,    0,  129,    2, 0x0a /* Public */,
      15,    0,  130,    2, 0x0a /* Public */,
      16,    1,  131,    2, 0x0a /* Public */,
      17,    0,  134,    2, 0x0a /* Public */,
      18,    0,  135,    2, 0x0a /* Public */,
      19,    0,  136,    2, 0x0a /* Public */,
      20,    2,  137,    2, 0x0a /* Public */,
      21,    1,  142,    2, 0x0a /* Public */,
      22,    0,  145,    2, 0x0a /* Public */,
      23,    0,  146,    2, 0x0a /* Public */,
      24,    0,  147,    2, 0x0a /* Public */,
      25,    0,  148,    2, 0x0a /* Public */,
      26,    0,  149,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    4,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Double,   11,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    4,    5,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void EditDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<EditDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->select_ingredient((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 1: _t->unit_changed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->ingredient_name_changed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->amount_type_changed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->amount_int_changed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->amount_float_changed((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 6: _t->add_ingredient(); break;
        case 7: _t->delete_ingredient(); break;
        case 8: _t->ingredient_section_changed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->add_ingredient_section(); break;
        case 10: _t->move_ingredient_up(); break;
        case 11: _t->move_ingredient_down(); break;
        case 12: _t->select_instruction((*reinterpret_cast< const QModelIndex(*)>(_a[1])),(*reinterpret_cast< const QModelIndex(*)>(_a[2]))); break;
        case 13: _t->section_changed((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 14: _t->add_instruction_section(); break;
        case 15: _t->remove_instruction_section(); break;
        case 16: _t->instructions_text_changed(); break;
        case 17: _t->update_ok_button(); break;
        case 18: _t->unit_converter(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject EditDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_EditDialog.data,
    qt_meta_data_EditDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *EditDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EditDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_EditDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int EditDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 19;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
